@@ -380,6 +380,11 @@ up_client_changed (CcPowerPanel *self)
 
   if (n_batteries > 1)
     hdy_preferences_group_set_title (self->battery_section, _("Batteries"));
+  else if (on_ups) {
+    /* Translators: UPS is an Uninterruptible Power Supply:
+       * https://en.wikipedia.org/wiki/Uninterruptible_power_supply */
+      hdy_preferences_group_set_title (self->battery_section, _("UPS"));
+  }
   else
     hdy_preferences_group_set_title (self->battery_section, _("Battery"));
 
